@@ -1,6 +1,6 @@
 #!/bin/sh
 
 cd /opt/handsoff
-python handsoff.py
+run-standalone.sh python handsoff.py
 
 exit 0
